CurveError

Enum CurveError 

pub enum CurveError {
    TooFewNodes {
        found: usize,
    },
    NodesNotIncreasing {
        at_index: usize,
    },
    NonPositiveDiscount {
        at_index: usize,
        value: f64,
    },
    AnchorNotUnit,
    InvalidTime {
        t: f64,
    },
    Type(TypeError),
    DuplicateNode {
        t: f64,
    },
}
Error returned when constructing or evaluating a discount curve.

Examples

use regit_curves::errors::CurveError;

let err = CurveError::TooFewNodes { found: 1 };
assert_eq!(
    format!("{err}"),
    "curve needs at least two nodes, found 1",
);

Variants



TooFewNodes

Fewer than two nodes were supplied.

Fields

found: usize

Number of nodes that were supplied.



NodesNotIncreasing

Node times are not strictly increasing.

Fields

at_index: usize

Index of the first node that breaks the invariant.



NonPositiveDiscount

A discount factor at a node was not strictly positive.

Fields

at_index: usize

Index of the offending node.

value: f64

The offending value.



AnchorNotUnit

The first node is not at t = 0 or its discount factor is not 1.



InvalidTime

t is negative or non-finite.

Fields

t: f64

The offending value of t.



Type(TypeError)

A day-count query failed.



DuplicateNode

Two construction points have the same t (used in slope / spline construction).

Fields

t: f64

The duplicated time.