Compounding

Enum Compounding 

pub enum Compounding {
    Simple,
    Continuous,
    Periodic {
        periods_per_year: u32,
    },
}
Compounding convention for converting between discount factors and zero rates.

For time t > 0 and zero rate r:

VariantDiscount factorInverse
SimpleD = 1 / (1 + r*t)r = (1/D - 1) / t
ContinuousD = exp(-r*t)r = -ln(D) / t
Periodic { n }D = (1 + r/n)^(-n*t)r = n * (D^(-1/(n*t)) - 1)

At t = 0 the discount factor is exactly 1 for any rate, and the “rate implied by D = 1” is 0. All other queries with t = 0 are errors.

Variants



Simple

Simple interest: D = 1 / (1 + r * t).



Continuous

Continuously compounded: D = exp(-r * t).



Periodic

Periodic compounding with n periods per year.

Fields

periods_per_year: u32

Number of compounding periods per year (1 annual, 2 semi-annual, 4 quarterly, 12 monthly).

Implementations

Source

impl Compounding

pub fn discount_from_rate(self, rate: f64, t: f64) -> Result<f64, TypeError>

Returns the discount factor implied by a zero rate over time t.

Errors
Examples
use regit_curves::types::Compounding;

let d = Compounding::Continuous.discount_from_rate(0.05, 2.0).unwrap();
assert!((d - (-0.10_f64).exp()).abs() < 1e-15);
pub fn rate_from_discount(self, discount: f64, t: f64) -> Result<f64, TypeError>

Returns the zero rate implied by a discount factor over time t.

At t = 0 and discount = 1 the function returns 0.0. Any other t = 0 query is rejected because the rate is undefined.

Errors
Examples
use regit_curves::types::Compounding;

let r = Compounding::Continuous
    .rate_from_discount((-0.10_f64).exp(), 2.0)
    .unwrap();
assert!((r - 0.05).abs() < 1e-15);